@@ -6,7 +6,7 @@ from logging import handlers
 
 from colorlog import colorlog
 
-from ftools.f_general import get_path_root
+from FEADRE_AI.f_general import get_path_root
 
 '''
 在项目根目录建立 logs 文件夹
@@ -16,7 +16,11 @@ args=(os.path.abspath(os.getcwd() + "/info.log"),"midnight", 1, 6,'utf-8')
 
 
 def Singleton(cls):
-    # 单例
+    '''
+    单例  通过 @Singleton
+    :param cls:
+    :return:
+    '''
     _instance = {}
 
     def _singleton(*args, **kargs):
