@@ -7,9 +7,9 @@ from pycocotools.coco import COCO
 from torch.utils.data import Dataset
 import numpy as np
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.datas.dta_heighten.fmosaic import get_mosaic_img, mixup
-from ftools.ai.object_detection.boxes.f_kps import fsplit_kps
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.datas.dta_heighten.fmosaic import get_mosaic_img, mixup
+from FEADRE_AI.ai.object_detection.boxes.f_kps import fsplit_kps
 
 
 class CustomCocoDataset(Dataset):
@@ -372,7 +372,7 @@ class HeightenCocoDataset(CustomCocoDataset):
                                             thr_area=self.thr_area,
                                             )
             # debug
-            # from ftools.ai.picture.f_show import f_show_od_np4plt_v3
+            # from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3
             # f_show_od_np4plt_v3(img_np, g_ltrb=target['boxes'],
             #                                 g_texts=target['labels'].astype(np.int).tolist())
 
@@ -388,7 +388,7 @@ class HeightenCocoDataset(CustomCocoDataset):
                                    mixup_scale=(0.5, 1.5),
                                    )
             # debug
-            # from ftools.ai.picture.f_show import f_show_od_np4plt_v3
+            # from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3
             # f_show_od_np4plt_v3(img_np, g_ltrb=target['boxes'],
             #                     g_texts=target['labels'].astype(np.int).tolist())
         else:
@@ -398,9 +398,9 @@ class HeightenCocoDataset(CustomCocoDataset):
 
 
 if __name__ == '__main__':
-    from ftools.ai.datas.data_factory import CLS4collate_fn
-    from ftools.ai.datas.z_dataloader import get_data_cocomin, get_data_type3
-    from ftools.ai.picture.f_show import f_show_od_np4plt_v3, f_show_od_np4cv
+    from FEADRE_AI.ai.datas.data_factory import CLS4collate_fn
+    from FEADRE_AI.ai.datas.z_dataloader import get_data_cocomin, get_data_type3
+    from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3, f_show_od_np4cv
     import numpy as np
 
 
