@@ -6,13 +6,13 @@ import cv2
 import numpy as np
 from numpy import random
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.object_detection.boxes.f_boxes import ltwh2ltrb, fverify_bbox
-from ftools.ai.datas.dataset_coco import CustomCocoDataset
-from ftools.ai.object_detection.boxes.f_kps import fcre_kps_min_bbox, fverify_kps, fsplit_kps
-from ftools.ai.picture.f_size_handler import resize_np_keep
-from ftools.ai.picture.f_show import f_show_od_np4plt_v3, f_show_kp_np4cv, f_show_od_np4cv
-from ftools.ai.datas.z_dataloader import KEYPOINTS_Mirror
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.object_detection.boxes.f_boxes import ltwh2ltrb, fverify_bbox
+from FEADRE_AI.ai.datas.dataset_coco import CustomCocoDataset
+from FEADRE_AI.ai.object_detection.boxes.f_kps import fcre_kps_min_bbox, fverify_kps, fsplit_kps
+from FEADRE_AI.ai.picture.f_size_handler import resize_np_keep
+from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3, f_show_kp_np4cv, f_show_od_np4cv
+from FEADRE_AI.ai.datas.z_dataloader import KEYPOINTS_Mirror
 
 
 def ftransform_nanodet_train(size_wh_input):
@@ -1099,7 +1099,7 @@ def x_random_rotation4np(img_np, boxes_ltrb_np, kps_3d_np, degree=10):
 
 
 def t_transformer():
-    from ftools.ai.datas.z_dataloader import get_data_voc2007, get_data_widerface, get_data_face5, \
+    from FEADRE_AI.ai.datas.z_dataloader import get_data_voc2007, get_data_widerface, get_data_face5, \
         get_data_face98, get_data_lsp
     mode = 'keypoints'  # bbox segm keypoints caption
 
