@@ -1,9 +1,9 @@
 import os
 
-from ftools.ai.datas.coco.coco_api import f_look_coco_type, f_coco_verify_info
-from ftools.ai.datas.data_factory import fcre_dataload
-from ftools.ai.gpu.webapi.translate import translate_baidu
-from ftools.ai.picture.f_show import f_show_kp_np4cv
+from FEADRE_AI.ai.datas.coco.coco_api import f_look_coco_type, f_coco_verify_info
+from FEADRE_AI.ai.datas.data_factory import fcre_dataload
+from FEADRE_AI.ai.gpu.webapi.translate import translate_baidu
+from FEADRE_AI.ai.picture.f_show import f_show_kp_np4cv
 
 KEYPOINTS_Mirror = {  # 水平翻转 这个要和数据遍历对起
     'face98': [[32, 31], [30, 29], [28, 27],
