@@ -16,15 +16,15 @@ import torch.nn as nn
 from pycocotools.cocoeval import COCOeval
 from torch.cuda.amp import GradScaler, autocast
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.fits.fweight import save_weight
-from ftools.ai.object_detection.boxes.f_boxes import ltrb2ltwh
-from ftools.ai.datas.coco.fcocoeval import FCOCOeval
-from ftools.ai.fmodels.tools.ema import ModelEMA
-from ftools.ai.object_detection.boxes.f_kps import fsplit_kps
-from ftools.ai.picture.f_show import f_show_od_np4plt_v3, f_show_kp_np4cv
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.fits.fweight import save_weight
+from FEADRE_AI.ai.object_detection.boxes.f_boxes import ltrb2ltwh
+from FEADRE_AI.ai.datas.coco.fcocoeval import FCOCOeval
+from FEADRE_AI.ai.fmodels.tools.ema import ModelEMA
+from FEADRE_AI.ai.object_detection.boxes.f_kps import fsplit_kps
+from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3, f_show_kp_np4cv
 
-from ftools.f_general import get_path_root
+from FEADRE_AI.f_general import get_path_root
 
 
 class FModelBase(nn.Module):
@@ -99,6 +99,16 @@ class InfoRes4test:
 
 
 class FitExecutorBase:
+    '''
+    需传入
+        fun_loss
+        fun_test
+        dataloader_train
+        dataloader_test
+
+    @abstractmethod
+        def ftest(self, epoch)
+    '''
 
     def __init__(self, cfg, model,
                  fun_loss=None, fun_test=None,
@@ -133,6 +143,7 @@ class FitExecutorBase:
         else:
             self.tb_writer = None
 
+        # ema更新
         if self.cfg.IS_EMA and self.model is not None and self.dataloader_train is not None:
             self.ema_model = ModelEMA(self.model, 0.9998)
             # 开始 * max_iter数
@@ -141,7 +152,10 @@ class FitExecutorBase:
             self.ema_model = None
 
     def frun(self):
-
+        '''
+        总调度
+        :return:
+        '''
         # 重新训练时 继续冻结
         if self.cfg.NUMS_LOCK_WEIGHT_DICT is not None:
             n_time = len(self.cfg.NUMS_LOCK_WEIGHT_DICT[::-1])
@@ -159,6 +173,8 @@ class FitExecutorBase:
                 if isinstance(self.model, nn.Module):
                     # 有时间 model可能 是list
                     self.model.train()
+
+                # 冻结参数方法
                 if self.cfg.NUMS_LOCK_WEIGHT_DICT is not None:
                     _mask = self.cfg.NUMS_LOCK_WEIGHT_DICT == epoch  # 这里只用结果的第一个
                     if _mask.any():
@@ -175,6 +191,7 @@ class FitExecutorBase:
 
             if self.dataloader_train is not None \
                     and self.is_open(epoch, self.cfg.NUM_WEIGHT_SAVE_DICT):
+                # 如果是训练 到达保存的条件
                 print('训练完成正在保存模型...')
                 save_weight(
                     path_save=self.cfg.PATH_SAVE_WEIGHT,
@@ -191,6 +208,7 @@ class FitExecutorBase:
             if self.dataloader_test is not None and self.is_open(epoch, self.cfg.NUMS_TEST_DICT):
 
                 if self.cfg.IS_TEST is None and self.cfg.IS_VAL is None:
+                    # 不需要测试和验证
                     flog.warning('cfg.IS_TEST,cfg.IS_VAL 均为空')
                     return
 
@@ -244,8 +262,10 @@ class FitExecutorBase:
         for i, datas_batch in enumerate(self.dataloader_train):
             # 这里输出的是CPU 数据 dataloader 之前是多进程使用CPU兼容性好 这里需要转换
             if epoch < cfg.NUM_WARMUP and cfg.IS_WARMUP:
+                # 这是热身轮 写死的非线
                 now_lr = cfg.LR_BASE * pow((i + epoch * epoch_size) * 1. / (cfg.NUM_WARMUP * epoch_size), 4)
                 self.update_lr(cfg.OPTIMIZER, now_lr)
+
             elif epoch == cfg.NUM_WARMUP:
                 self.update_lr(cfg.OPTIMIZER, cfg.LR_BASE)
 
@@ -392,6 +412,11 @@ class FitExecutorBase:
 
 
 class FitExecutorCOCO_t(FitExecutorBase):
+    '''
+    自带 coco 验证
+    @abstractmethod
+        def _ftest_impl 具体实现
+    '''
 
     def __init__(self, cfg, model, fun_loss=None, fun_test=None, dataloader_train=None, dataloader_test=None) -> None:
         super().__init__(cfg, model, fun_loss, fun_test, dataloader_train, dataloader_test)
@@ -534,6 +559,9 @@ class FitExecutor4OD(FitExecutorCOCO_t):
         super().__init__(cfg, model, fun_loss, fun_test, dataloader_train, dataloader_test)
 
     def set_info_res4test(self, info_res4test, log_dict, id_img, is_no_pos=False, **kargs):
+        '''
+        这个用于 tf 显示
+        '''
         info_res4test.ids_img.append(id_img)  # 全局
         if is_no_pos:
             info_res4test.nums_pos.append(0)
