@@ -12,19 +12,20 @@ import onnxruntime
 import torch
 from torch.backends import cudnn
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.fits.f_fit_tools import SmoothedValue, FitExecutorBase, FitExecutor4OD, FitExecutor4KPS
-from ftools.ai.picture.f_show import f_show_od_np4plt_v3, draw_text_chinese4cv
-from ftools.f_general import get_img_file
-from ftools.ai.fits.f_predictfun import batch_nms_v2
-from ftools.general.fsys.fcamera import init_video
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.fits.f_fit_tools import SmoothedValue, FitExecutorBase, FitExecutor4OD, FitExecutor4KPS
+from FEADRE_AI.ai.picture.f_show import f_show_od_np4plt_v3, draw_text_chinese4cv
+from FEADRE_AI.f_general import get_img_file
+from FEADRE_AI.ai.fits.f_predictfun import batch_nms_v2
+from FEADRE_AI.general.fsys.fcamera import init_video
 
 
 class DispatchTask:
-    def __init__(self, fun_task_cfg=None) -> None:
+    def __init__(self, fun_task_cfg=None, fit_executor_obj=None) -> None:
         super().__init__()
         self.init_sys(None)
         self.fun_task_cfg = fun_task_cfg
+        self.fit_executor_obj = fit_executor_obj
 
     def init_sys(self, cfg):
         # -----------通用系统配置----------------
@@ -98,22 +99,23 @@ class DispatchTask:
         else:
             size = cfg.SIZE_WH_INPUT_TRAIN
 
+        # 这些参数在 FCFG_BASE 中有
         _text_dict = {
-            'dataset_name': cfg.DATA_INFO.dataset_name,
-            'tb_writer_info': tb_writer_info,
+            'dataset_name': cfg.DATA_INFO.dataset_name,  # 这个需要处理
+            'tb_writer_info': tb_writer_info,  # 指定TB 目录
             'device': cfg.DEVICE,
-            'num_vis_z': cfg.NUM_VIS_Z,
-            'num_workers': cfg.NUM_WORKERS,
+            'num_vis_z': cfg.NUM_VIS_Z,  # OD 测试时可视化数量
+            'num_workers': cfg.NUM_WORKERS,  # 多进程数
             'path_save_weight': cfg.PATH_SAVE_WEIGHT,
-            'warmup_info': warmup_info,
-            'is_visual': cfg.IS_VISUAL,
-            'size': size,
+            'warmup_info': warmup_info,  # 热身轮数
+            'is_visual': cfg.IS_VISUAL,  # 可视化  自己用
+            'size': size,  # OD 输入图片尺寸
             'batch_train': cfg.DATA_INFO.batch_train,
-            'mode_train': cfg.DATA_INFO.mode_train,
-            'ema': cfg.IS_EMA,
-            'maps_def_max': cfg.MAPS_DEF_MAX,
-            'is_mosaic': cfg.IS_MOSAIC,
-            'is_mixup': cfg.IS_MIXUP,
+            'mode_train': cfg.DATA_INFO.mode_train,  # OD 训练od或keypoint
+            'ema': cfg.IS_EMA,  # 使用EMA 平滑
+            'maps_def_max': cfg.MAPS_DEF_MAX,  # OD COCO map保存阀值
+            'is_mosaic': cfg.IS_MOSAIC,  # OD
+            'is_mixup': cfg.IS_MIXUP,  # OD
         }
 
         separator = '  \n'
@@ -179,6 +181,16 @@ class DispatchTask:
         time_text = str(datetime.timedelta(seconds=int(time.time() - t00)))
         return time_text
 
+    def run_train_v2(self):
+        assert self.fit_executor_obj is not None
+        t00 = time.time()
+
+        self.show_args(self.fit_executor_obj.cfg)
+
+        self.fit_executor_obj.frun()
+        time_text = str(datetime.timedelta(seconds=int(time.time() - t00)))
+        return time_text
+
 
 ''' ----------------- 检测任务执行者 --------------------- '''
 
