@@ -468,8 +468,8 @@ def darknet_light(pretrained=False, device='cpu', **kwargs):
 
 
 if __name__ == '__main__':
-    from ftools.ai.fmodels.f_layer_get import ModelOuts4DarkNet53
-    from ftools.ai.fmodels.model_look import f_look_summary
+    from FEADRE_AI.ai.fmodels.f_layer_get import ModelOuts4DarkNet53
+    from FEADRE_AI.ai.fmodels.model_look import f_look_summary
     # model = darknet19(pretrained=True, device='cpu') # 1
     # model = darknet53(pretrained=True, device='cpu')  # 2
     # model = ModelOuts4DarkNet53(model)
