@@ -3,7 +3,7 @@ from torch import nn
 import torch.nn.functional as F
 import numpy as np
 
-from ftools.ai.fmodels.model_subassembly import FConv2d
+from FEADRE_AI.ai.fmodels.model_subassembly import FConv2d
 
 
 class Bottleneck(nn.Module):
