@@ -1,7 +1,7 @@
 import torch
 import torch.nn as nn
 
-from ftools.ai.fmodels.f_fun_activation import Mish, SiLU
+from FEADRE_AI.ai.fmodels.f_fun_activation import Mish, SiLU
 
 '''
 模型组件
