@@ -4,8 +4,8 @@ import torch
 from torchvision import models
 import torch.nn as nn
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.fmodels.f_layer_get import ModelOuts4Resnet
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.fmodels.f_layer_get import ModelOuts4Resnet
 
 
 class Net3(torch.nn.Module):
