@@ -4,7 +4,7 @@ import random
 
 import requests
 
-from ftools.FGLOBAL_VAR import GLOBAL
+from FEADRE_AI.FGLOBAL_VAR import GLOBAL
 
 '''
 API 翻译
