@@ -1,11 +1,11 @@
 import torch
 
-from ftools.GLOBAL_LOG import flog
-from ftools.ai.fits.olf.floss import f_bce_loss
-from ftools.ai.object_detection.boxes.f_boxes import bbox_iou_v3, ltrb2xywh, xywh2ltrb
-from ftools.ai.calc.f_calc_adv import f_cre_grid_cells
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.ai.fits.olf.floss import f_bce_loss
+from FEADRE_AI.ai.object_detection.boxes.f_boxes import bbox_iou_v3, ltrb2xywh, xywh2ltrb
+from FEADRE_AI.ai.calc.f_calc_adv import f_cre_grid_cells
 
-from ftools.ai.picture.f_show import f_show_od_ts4plt_v3
+from FEADRE_AI.ai.picture.f_show import f_show_od_ts4plt_v3
 import numpy as np
 import torch.nn.functional as F
 
@@ -254,7 +254,7 @@ def match4atss(gltrb_i_b, anc_ltrb_i, nums_dim_t_list, num_atss_topk=9, glabels_
     if is_visual or msak_pos_1d.sum() == 0 or (mask_pos4all.sum(0) == 0).any():
         # 修正后还不行的进来 这里
         flog.error('双重修正后不可能没有 mask_pos4iou= %s, mask_pos4all= %s ' % (mask_pos4iou.sum(0), mask_pos4all.sum(0)))
-        from ftools.ai.picture import f_show_od_ts4plt_v3
+        from FEADRE_AI.ai.picture import f_show_od_ts4plt_v3
         # ***********  debug 可视  每层选9个匹配27(3*9)个正例可视化  *****************
         # 多个gt 对应一个anc 进行转换显示
         dim, ngt = mask_pos4distances.shape
