@@ -9,8 +9,8 @@ from PIL import Image, ImageDraw, ImageFont
 from torchvision import transforms
 import matplotlib.pyplot as plt
 
-from ftools.GLOBAL_LOG import flog
-from ftools.general.FColor import fcre_color_indexes, COLORS_MAP, fget_color_random, fget_color_val, COLORS_RGB, \
+from FEADRE_AI.GLOBAL_LOG import flog
+from FEADRE_AI.general.FColor import fcre_color_indexes, COLORS_MAP, fget_color_random, fget_color_val, COLORS_RGB, \
     fhex2rgb
 
 '''
@@ -121,7 +121,7 @@ def f_show_od_ts4plt_v3(img_ts, g_ltrb=None, p_ltrb=None, is_recover_size=False,
     assert isinstance(img_ts, torch.Tensor)
     # c,h,w -> h,w,c
     if is_normal:
-        from ftools.ai.datas.dta_heighten.f_data_heighten4target import f_recover_normalization4ts_v2
+        from FEADRE_AI.ai.datas.dta_heighten.f_data_heighten4target import f_recover_normalization4ts_v2
         img_ts = img_ts.clone()
         img_ts = f_recover_normalization4ts_v2(img_ts)
     img_np = img_ts.cpu().numpy().astype(np.uint8).transpose((1, 2, 0))
