@@ -1,7 +1,7 @@
 import torch  # This is all you need to use both PyTorch and TorchScript!
 from torchvision import models
 
-from ftools.f_general import fshow_time
+from FEADRE_AI.f_general import fshow_time
 
 print(torch.__version__)
 
